summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/network/tqhttp.h
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/network/tqhttp.h')
-rw-r--r--tqtinterface/qt4/src/network/tqhttp.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tqtinterface/qt4/src/network/tqhttp.h b/tqtinterface/qt4/src/network/tqhttp.h
index 37ab916..fb20d4f 100644
--- a/tqtinterface/qt4/src/network/tqhttp.h
+++ b/tqtinterface/qt4/src/network/tqhttp.h
@@ -173,8 +173,8 @@ class TQM_EXPORT_HTTP TQHttp : public TQNetworkProtocol
public:
TQHttp();
- TQHttp( TQObject* tqparent, const char* name = 0 ); // ### TQt 4.0: make tqparent=0 and get rid of the TQHttp() constructor
- TQHttp( const TQString &hostname, TQ_UINT16 port=80, TQObject* tqparent=0, const char* name = 0 );
+ TQHttp( TQObject* parent, const char* name = 0 ); // ### TQt 4.0: make parent=0 and get rid of the TQHttp() constructor
+ TQHttp( const TQString &hostname, TQ_UINT16 port=80, TQObject* parent=0, const char* name = 0 );
virtual ~TQHttp();
int supportedOperations() const;